@@ -743,6 +743,13 @@ class ucs(object):
         ud.debug(ud.LDAP, level, text)
         ud.debug(ud.LDAP, level, traceback.format_exc())
 
+    def check_syncmode_ucs(self, property_key):
+        # if sync is read (sync from AD) or none, there is nothing to do
+        if self.property[property_key].sync_mode in ['read', 'none']:
+            ud.debug(ud.LDAP, ud.INFO, "sync_from_ucs ignored, sync_mode is %s" % self.property[property_key].sync_mode)
+            return False
+        return True
+
     def __sync_file_from_ucs(self, filename, append_error='', traceback_level=ud.WARN):
         """sync changes from UCS stored in given file"""
         try:
@@ -780,6 +787,10 @@ class ucs(object):
         _attr = new or old
         _mod, key = self.identify_udm_object(dn, _attr)
 
+        if not key or not self.check_syncmode_ucs(key):
+            ud.debug(ud.LDAP, ud.INFO, "__sync_file_from_ucs: No mapping was found for dn: %s" % dn)
+            return True
+
         if not new:
             change_type = "delete"
             ud.debug(ud.LDAP, ud.INFO, "__sync_file_from_ucs: object was deleted")
@@ -1395,56 +1406,10 @@ class ucs(object):
         """
         # NOTE: pre_mapped_ad_dn means: original ad_dn (i.e. before _object_mapping)
         # this function gets an object from the ad class, which should be converted into a ucs module
-
-        # if sync is write (sync to AD) or none, there is nothing to do
-        if not property_type or self.property[property_type].sync_mode in ['write', 'none']:
-            if property_type:
-                ud.debug(ud.LDAP, ud.INFO, "sync_to_ucs ignored, sync_mode is %s" % self.property[property_type].sync_mode)
-            else:
-                ud.debug(ud.LDAP, ud.INFO, "sync_to_ucs ignored, no mapping defined")
+        if not self.check_syncmode_ad(property_type, object):
             return True
-
-        if object['dn'].find('\\0ACNF:') > 0:
-            ud.debug(ud.LDAP, ud.PROCESS, 'Ignore conflicted object: %s' % object['dn'])
-            return True
-
         try:
-            guid = decode_guid(original_object.get('attributes').get('objectGUID')[0])
-
-            object['changed_attributes'] = []
-            if object['modtype'] == 'modify' and original_object:
-                old_ad_object = self.adcache.get_entry(guid)
-                ud.debug(ud.LDAP, ud.INFO, "sync_to_ucs: old_ad_object: %s" % old_ad_object)
-                ud.debug(ud.LDAP, ud.INFO, "sync_to_ucs: new_ad_object: %s" % original_object['attributes'])
-                original_attributes = original_object['attributes']
-                if old_ad_object:
-                    for attr in original_object['attributes']:
-                        if old_ad_object.get(attr) != original_attributes.get(attr):
-                            object['changed_attributes'].append(attr)
-                    for attr in old_ad_object:
-                        if old_ad_object.get(attr) != original_attributes.get(attr) and attr not in object['changed_attributes']:
-                            object['changed_attributes'].append(attr)
-                    if not (set(object['changed_attributes']) - self.irrelevant_attributes):
-                        if property_type == "user" \
-                           and self.configRegistry.is_false('connector/ad/mapping/user/password/disabled', True) \
-                           and not self.configRegistry.is_true('connector/ad/mapping/user/password/kinit', False):
-                            if object['attributes'].get('pwdLastSet', [b'1'])[0] == b'0':
-                                ud.debug(ud.LDAP, ud.INFO, "sync_to_ucs: pwdLastSet is 0. Do not ignore %r" % (original_object['dn'],))
-                            else:
-                                ud.debug(ud.LDAP, ud.INFO, "sync_to_ucs: ignore %r" % (original_object['dn'],))
-                                return True
-                        else:
-                            ud.debug(ud.LDAP, ud.INFO, "sync_to_ucs: ignore %r" % (original_object['dn'],))
-                            ud.debug(ud.LDAP, ud.ALL, "sync_to_ucs: changed_attributes=%s" % (object['changed_attributes'],))
-                            return True
-                else:
-                    object['changed_attributes'] = list(original_attributes.keys())
-            ud.debug(ud.LDAP, ud.INFO, "The following attributes have been changed: %s" % object['changed_attributes'])
-
-            result = False
-
-            # Check if the object on UCS side should be synchronized
-            #  https://forge.univention.org/bugzilla/show_bug.cgi?id=37351
+            guid = decode_guid(object.get('attributes').get('objectGUID')[0])
             if property_type == "windowscomputer":
                 old_ucs_ldap_object = {}
                 old_ucs_ldap_object['dn'] = object.get('olddn', object['dn'])
@@ -1512,25 +1477,40 @@ class ucs(object):
                     result = True
 
             if object['modtype'] == 'modify':
-                res = self.modify_in_ucs(property_type, object, module, position)
-                if res:
-                    if object['dn'].lower() != res.lower():  # This "modify" resulted in a modrdn in UDM even though the DN didn't change in AD
-                        self._remove_dn_mapping(object['dn'], pre_mapped_ad_dn)
-                        object['dn'] = res
-                    old_con_dn = original_object.get('olddn')
-                    if old_con_dn and pre_mapped_ad_dn != old_con_dn:
-                        self._remove_dn_mapping(object['olddn'], old_con_dn)
-                        self._update_group_related_caches(
-                            property_type,
-                            old_con_dn=old_con_dn,
-                            old_ucs_dn=object['olddn'],
-                            new_con_dn=pre_mapped_ad_dn,
-                            new_ucs_dn=object['dn'],
-                        )
+
+                modified_dn = self.modify_in_ucs(property_type, object, module, position)
+                modified_parent_dn = self.lo.parentDn(modified_dn).lower()
+                parent_object_dn = self.lo.parentDn(object['dn']).lower()
+
+                object['olddn'] = object.get('olddn', object['dn'])
+                if not self.lo.compare_dn(modified_parent_dn, parent_object_dn):
+                    # additionally move the object if position changed
+                    # TODO: object['dn'] seems to be the correct target, but why?
+                    ud.debug(ud.LDAP, ud.INFO, "sync_to_ucs: move object from %r to %r" % (modified_dn, object['dn']))
+                    ucs_object = univention.admin.objects.get(module, None, self.lo, dn=modified_dn, position='')
+                    ucs_object.open()
+                    ucs_object.move(object['dn'])
+                elif object['dn'].lower() != modified_dn.lower():
+                    # TODO: in this case object['dn'] is the unchanged UCS DN, why?
+                    # update group cache
+                    object['dn'] = modified_dn
+
+                old_con_dn = original_object.get('olddn', pre_mapped_ad_dn)
+                self._update_group_related_caches(
+                    property_type,
+                    old_con_dn=old_con_dn,
+                    old_ucs_dn=object['olddn'],
+                    new_con_dn=pre_mapped_ad_dn,
+                    new_ucs_dn=object['dn'],
+                )
+
+                if not self.lo.compare_dn(object['olddn'], object['dn']):
+                    self._remove_dn_mapping(object['olddn'], old_con_dn)
+
                 # Finally commit the current DNs to the DN mapping cache
                 self._check_dn_mapping(object['dn'], pre_mapped_ad_dn)
                 self.adcache.add_entry(guid, original_object.get('attributes'))
-                result = True if res else res
+                result = True
 
             if not result:
                 ud.debug(ud.LDAP, ud.WARN, "Failed to get Result for DN (%r)" % (object['dn'],))
